@@ -5,6 +5,8 @@
 # Distributed under the terms of the GPL License.
 from copy import copy
 from typing import Any, Dict, List, Optional, Set, Tuple
+from mitosheet.code_chunks.code_chunk import CodeChunk
+from mitosheet.code_chunks.step_performers.dataframe_steps.dataframe_rename_code_chunk import DataframeRenameCodeChunk
 
 from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
@@ -25,10 +27,6 @@ class DataframeRenameStepPerformer(StepPerformer):
     def step_type(cls) -> str:
         return 'dataframe_rename'
 
-    @classmethod
-    def step_display_name(cls) -> str:
-        return 'Renamed a Dataframe'
-
     @classmethod
     def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
         sheet_index = params['sheet_index']
@@ -59,29 +57,16 @@ class DataframeRenameStepPerformer(StepPerformer):
         }
 
     @classmethod
-    def transpile( # type: ignore
+    def transpile(
         cls,
         prev_state: State,
         post_state: State,
+        params: Dict[str, Any],
         execution_data: Optional[Dict[str, Any]],
-        sheet_index: int,
-        old_dataframe_name: str,
-        new_dataframe_name: str
-    ) -> List[str]:
-        if old_dataframe_name == new_dataframe_name:
-            return []
-        return [f'{post_state.df_names[sheet_index]} = {old_dataframe_name}']
-
-    @classmethod
-    def describe( # type: ignore
-        cls,
-        sheet_index: int,
-        old_dataframe_name: str,
-        new_dataframe_name: str,
-        df_names=None,
-        **params
-    ) -> str:
-        return f'Renamed {old_dataframe_name} to {new_dataframe_name}'
+    ) -> List[CodeChunk]:
+        return [
+            DataframeRenameCodeChunk(prev_state, post_state, params, execution_data)
+        ]
 
     @classmethod
     def get_modified_dataframe_indexes( # type: ignore
